"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[594],{86594:function(e,t,r){r.r(t),r.d(t,{FallthroughRoot:function(){return f}});var n=r(32030),i=r(34595),o=r(7838),s=r(89646),a=r(75453),l=r(325),c=r(27601),p=r(39061),d=r(76336),u=r(25582),x=r(32289),h=function(){var e=(0,c.TH)(),t="".concat(e.pathname).concat(e.search);return(0,x.jsx)(c.l_,{to:"/instance".concat(t)})},f=function(){return(0,x.jsxs)(c.rs,{children:[(0,x.jsx)(c.AW,{path:["/runs/(.*)?","/assets/(.*)?","/scheduler"],children:(0,x.jsx)(h,{})}),(0,x.jsx)(c.AW,{path:"/home",children:(0,x.jsx)(j,{})}),(0,x.jsx)(c.AW,{path:"*",children:(0,x.jsx)(j,{})})]})},j=function(){var e=l.useContext(d.C5),t=e.allRepos,r=e.loading,h=e.locationEntries;if(r)return(0,x.jsx)(n.x,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,x.jsxs)(n.x,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,x.jsx)(i.$,{purpose:"section"}),(0,x.jsx)("div",{style:{color:o.w.Gray600},children:"Loading workspace\u2026"})]})});if(h.length&&0===t.length)return(0,x.jsx)(c.l_,{to:"/workspace"});var f=t.filter((function(e){return e.repository.pipelines.length>0}));if(f.every((function(e){return e.repository.pipelines.every((function(e){return(0,p.pv)(e.name)}))})))return(0,x.jsx)(c.l_,{to:"/instance/assets"});if(1===f.length&&1===f[0].repository.pipelines.length){var j=f[0],g=j.repository.pipelines[0];return(0,x.jsx)(c.l_,{to:(0,u.jT)({repoName:j.repository.name,repoLocation:j.repositoryLocation.name,pipelineName:g.name,isJob:g.isJob})})}if(f.length>0)return(0,x.jsx)(c.l_,{to:"/instance"});var y=t[0];return(0,x.jsx)(n.x,{padding:{vertical:64},children:(0,x.jsx)(s.t,{icon:"no-results",title:y?"No jobs":"No repositories",description:y?"Your repository is loaded, but no jobs were found.":"Add a repository to get started.",action:(0,x.jsx)(a.fr,{href:"https://docs.dagster.io/getting-started",children:"View documentation"})})})};t.default=f},89646:function(e,t,r){r.d(t,{t:function(){return c}});r(325);var n=r(32030),i=r(7838),o=r(42658),s=r(34595),a=r(12745),l=r(32289),c=function(e){var t=e.title,r=e.description,c=e.icon,p=e.action,d=e.shrinkable,u=1===[t,r,p].filter(Boolean).length;return(0,l.jsxs)(n.x,{flex:{gap:20,alignItems:u?"center":"flex-start"},background:i.w.Gray50,padding:24,style:{margin:"auto",borderRadius:8,width:d?"initial":"max-content",maxWidth:500},children:["spinner"===c?(0,l.jsx)(s.$,{purpose:"section"}):"no-results"===c?(0,l.jsx)(o.JO,{name:"search",size:48,color:i.w.Gray400}):(0,l.jsx)(o.JO,{name:c,size:48,color:i.w.Gray400}),(0,l.jsxs)(n.x,{flex:{gap:8,direction:"column",alignItems:"flex-start"},children:[t&&(0,l.jsx)(a.pm,{style:{color:i.w.Gray900},children:t}),r&&(0,l.jsx)("div",{style:{color:i.w.Gray500},children:r}),p]})]})}}}]);
//# sourceMappingURL=594.7da09285.chunk.js.map